==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/PropertyUpdatedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyUpdatedEventArgsDescription } from "./PropertyUpdatedEventArgsDescription";
/**
 * @hidden
 */
export let PropertyUpdatedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class PropertyUpdatedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (PropertyUpdatedEventArgsDescriptionMetadata.a == null) {
                PropertyUpdatedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PropertyUpdatedEventArgsDescriptionMetadata.c(PropertyUpdatedEventArgsDescriptionMetadata.a);
            }
            if (a.k(PropertyUpdatedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(PropertyUpdatedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("PropertyName", "String");
            a.item("OldValueRef", "(w:OldValue,wf:OldValue)DataRef");
            a.item("NewValueRef", "(w:NewValue,wf:NewValue)DataRef");
        }
        static d(a) {
            PropertyUpdatedEventArgsDescriptionMetadata.b(a);
            a.ac("PropertyUpdatedEventArgs", () => new PropertyUpdatedEventArgsDescription());
            a.ab("PropertyUpdatedEventArgs", PropertyUpdatedEventArgsDescriptionMetadata.a);
        }
    }
    PropertyUpdatedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(PropertyUpdatedEventArgsDescriptionMetadata, 'PropertyUpdatedEventArgsDescriptionMetadata');
    PropertyUpdatedEventArgsDescriptionMetadata.a = null;
    return PropertyUpdatedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/PropertyUpdatedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyUpdatedEventArgsDescription } from "./PropertyUpdatedEventArgsDescription";
/**
 * @hidden
 */
export let PropertyUpdatedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class PropertyUpdatedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (PropertyUpdatedEventArgsDescriptionMetadata.a == null) {
                PropertyUpdatedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PropertyUpdatedEventArgsDescriptionMetadata.c(PropertyUpdatedEventArgsDescriptionMetadata.a);
            }
            if (a.k(PropertyUpdatedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(PropertyUpdatedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("PropertyName", "String");
            a.item("OldValueRef", "(w:OldValue,wf:OldValue)DataRef");
            a.item("NewValueRef", "(w:NewValue,wf:NewValue)DataRef");
        }
        static d(a) {
            PropertyUpdatedEventArgsDescriptionMetadata.b(a);
            a.ae("PropertyUpdatedEventArgs", () => new PropertyUpdatedEventArgsDescription());
            a.ad("PropertyUpdatedEventArgs", PropertyUpdatedEventArgsDescriptionMetadata.a);
        }
    }
    PropertyUpdatedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(PropertyUpdatedEventArgsDescriptionMetadata, 'PropertyUpdatedEventArgsDescriptionMetadata');
    PropertyUpdatedEventArgsDescriptionMetadata.a = null;
    return PropertyUpdatedEventArgsDescriptionMetadata;
})();
